/*
  Rhino test framework

   Copyright (C) 2011, 2012  Red Hat

This file is part of IcedTea.

IcedTea is free software; you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation; either version 2, or (at your option)
any later version.

IcedTea is distributed in the hope that it will be useful, but
WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
General Public License for more details.

You should have received a copy of the GNU General Public License
along with IcedTea; see the file COPYING.  If not, write to the
Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
02110-1301 USA.

Linking this library statically or dynamically with other modules is
making a combined work based on this library.  Thus, the terms and
conditions of the GNU General Public License cover the whole
combination.

As a special exception, the copyright holders of this library give you
permission to link this library with independent modules to produce an
executable, regardless of the license terms of these independent
modules, and to copy and distribute the resulting executable under
terms of your choice, provided that you also meet, for each linked
independent module, the terms and conditions of the license of that
module.  An independent module is a module which is not derived from
or based on this library.  If you modify this library, you may extend
this exception to your version of the library, but you are not
obligated to do so.  If you do not wish to do so, delete this
exception statement from your version.
*/

package org.RhinoTests;

import javax.script.ScriptEngine;
import javax.script.ScriptEngineFactory;
import javax.script.ScriptEngineManager;



/**
 * Basic ScriptEngine test suite. Following tests checks if ScriptEngineManager
 * is able to find particular scripting engine using various searching methods.
 * 
 * TODO: add new tests, comments
 * 
 * @author Pavel Tisnovsky
 */
public class ScriptEngineTest extends BaseRhinoTest {
    ScriptEngineManager engineManager;

    /**
     * Set up the test suite.
     */
    @Override
    protected void setUp(String[] args) {
        this.engineManager = new ScriptEngineManager();
    }

    /**
     * Tear down the test suite.
     */
    @Override
    protected void tearDown() {
        // empty block
        return;
    }

    /**
     * Helper method used to find scripting engine by its name.
     *
     * @param name name of scripting enginy
     * @return ScriptEngine instance
     * @throws Exception this exception is thrown if none script engine could be found.
     */
    private ScriptEngine tryToFindEngineByName(String name) throws Exception {
        assertNotNull(this.engineManager, "Script engine manager was not created");
        ScriptEngine scriptEngine = this.engineManager.getEngineByName(name);
        assertNotNull(scriptEngine, "JavaScript engine manager not found by name '" + name + "'");
        return scriptEngine;
    }

    /**
     * Helper method used to find scripting engine by its MIME type.
     *
     * @param mimeType MIME type of scripting engine
     * @return ScriptEngine instance
     * @throws Exception this exception is thrown if none script engine could be found.
     */
    private ScriptEngine tryToFindEngineByMimeType(String mimeType) throws Exception {
        assertNotNull(this.engineManager, "Script engine manager was not created");
        ScriptEngine scriptEngine = this.engineManager.getEngineByMimeType(mimeType);
        assertNotNull(scriptEngine, "JavaScript engine manager not found by MIME type '" + mimeType + "'");
        return scriptEngine;
    }

    /**
     * Test if script engine could be found using name "JavaScript"
     * @throws Exception this exception is thrown if none script engine could be found.
     */
    protected void testGetEngineByNameJavaScript() throws Exception {
        tryToFindEngineByName(Constants.EngineNames.ENGINE_NAME_JavaScript);
    }

    /**
     * Test if script engine could be found using name "javascript"
     * @throws Exception this exception is thrown if none script engine could be found.
     */
    protected void testGetEngineByNamejavascript() throws Exception {
        tryToFindEngineByName(Constants.EngineNames.ENGINE_NAME_javascript);
    }

    /**
     * Test if script engine could be found using name "ECMAScript"
     * @throws Exception this exception is thrown if none script engine could be found.
     */
    protected void testGetEngineByNameECMAScript() throws Exception {
        tryToFindEngineByName(Constants.EngineNames.ENGINE_NAME_ECMAScript);
    }

    /**
     * Test if script engine could be found using name "ecmascript"
     * @throws Exception this exception is thrown if none script engine could be found.
     */
    protected void testGetEngineByNameecmascript() throws Exception {
        tryToFindEngineByName(Constants.EngineNames.ENGINE_NAME_ecmascript);
    }

    /**
     * Test if script engine could be found using name "js"
     * @throws Exception this exception is thrown if none script engine could be found.
     */
    protected void testGetEngineByNamejs() throws Exception {
        tryToFindEngineByName(Constants.EngineNames.ENGINE_NAME_js);
    }

    /**
     * Test if script engine could be found using name "rhino"
     * @throws Exception this exception is thrown if none script engine could be found.
     */
    protected void testGetEngineByNameRhino() throws Exception {
        tryToFindEngineByName(Constants.EngineNames.ENGINE_NAME_rhino);
    }

    /**
     * Test if NPE is thrown if getEngineByName() is called with null.
     * @throws Exception if this test case fails.
     */
    protected void testGetEngineByNameNegative1() throws Exception {
        assertNotNull(this.engineManager, "Script engine manager was not created");
        try {
            @SuppressWarnings("unused")
            ScriptEngine scriptEngine = this.engineManager.getEngineByName(null);
        }
        catch (NullPointerException e)
        {
            return;
        }
        throw new Exception("NPE was not thrown as expected");
    }

    /**
     * Test if none script engine is found using wrong name.
     * @throws Exception if this test case fails.
     */
    protected void testGetEngineByNameNegative2() throws Exception {
        assertNotNull(this.engineManager, "Script engine manager was not created");
        ScriptEngine scriptEngine = this.engineManager.getEngineByName("");
        assertNull(scriptEngine, "JavaScript engine manager was found but it's not expected");
    }

    /**
     * Test if none script engine is found using wrong name.
     * @throws Exception if this test case fails.
     */
    protected void testGetEngineByNameNegative3() throws Exception {
        assertNotNull(this.engineManager, "Script engine manager was not created");
        ScriptEngine scriptEngine = this.engineManager.getEngineByName(" ");
        assertNull(scriptEngine, "JavaScript engine manager was found but it's not expected");
    }

    /**
     * Test if none script engine is found using wrong name.
     * @throws Exception if this test case fails.
     */
    protected void testGetEngineByNameNegative4() throws Exception {
        assertNotNull(this.engineManager, "Script engine manager was not created");
        ScriptEngine scriptEngine = this.engineManager.getEngineByName("   ");
        assertNull(scriptEngine, "JavaScript engine manager was found but it's not expected");
    }

    /**
     * Test if none script engine is found using wrong name.
     * @throws Exception if this test case fails.
     */
    protected void testGetEngineByNameNegative5() throws Exception {
        assertNotNull(this.engineManager, "Script engine manager was not created");
        ScriptEngine scriptEngine = this.engineManager.getEngineByName("\t");
        assertNull(scriptEngine, "JavaScript engine manager was found but it's not expected");
    }

    /**
     * Test if none script engine is found using wrong name.
     * @throws Exception if this test case fails.
     */
    protected void testGetEngineByNameNegative6() throws Exception {
        assertNotNull(this.engineManager, "Script engine manager was not created");
        ScriptEngine scriptEngine = this.engineManager.getEngineByName(" \t");
        assertNull(scriptEngine, "JavaScript engine manager was found but it's not expected");
    }

    /**
     * Test if none script engine is found using wrong name.
     * @throws Exception if this test case fails.
     */
    protected void testGetEngineByNameNegative7() throws Exception {
        assertNotNull(this.engineManager, "Script engine manager was not created");
        ScriptEngine scriptEngine = this.engineManager.getEngineByName("\b");
        assertNull(scriptEngine, "JavaScript engine manager was found but it's not expected");
    }

    /**
     * Test if none script engine is found using wrong name.
     * @throws Exception if this test case fails.
     */
    protected void testGetEngineByNameNegative8() throws Exception {
        assertNotNull(this.engineManager, "Script engine manager was not created");
        ScriptEngine scriptEngine = this.engineManager.getEngineByName("\b\b");
        assertNull(scriptEngine, "JavaScript engine manager was found but it's not expected");
    }

    /**
     * Test if none script engine is found using wrong name.
     * @throws Exception if this test case fails.
     */
    protected void testGetEngineByNameNegative9() throws Exception {
        assertNotNull(this.engineManager, "Script engine manager was not created");
        ScriptEngine scriptEngine = this.engineManager.getEngineByName(" \b\b");
        assertNull(scriptEngine, "JavaScript engine manager was found but it's not expected");
    }

    /**
     * Test if none script engine is found using wrong name.
     * @throws Exception if this test case fails.
     */
    protected void testGetEngineByNameNegative10() throws Exception {
        assertNotNull(this.engineManager, "Script engine manager was not created");
        ScriptEngine scriptEngine = this.engineManager.getEngineByName("\000");
        assertNull(scriptEngine, "JavaScript engine manager was found but it's not expected");
    }

    /**
     * Test if none script engine is found using wrong name.
     * @throws Exception if this test case fails.
     */
    protected void testGetEngineByNameNegative11() throws Exception {
        assertNotNull(this.engineManager, "Script engine manager was not created");
        ScriptEngine scriptEngine = this.engineManager.getEngineByName("\u0000");
        assertNull(scriptEngine, "JavaScript engine manager was found but it's not expected");
    }

    /**
     * Test if none script engine is found using wrong name.
     * @throws Exception if this test case fails.
     */
    protected void testGetEngineByNameNegative12() throws Exception {
        assertNotNull(this.engineManager, "Script engine manager was not created");
        ScriptEngine scriptEngine = this.engineManager.getEngineByName("really-wrong-name");
        assertNull(scriptEngine, "JavaScript engine manager was found but it's not expected");
    }

    /**
     * Test if none script engine is found using wrong name.
     * @throws Exception if this test case fails.
     */
    protected void testGetEngineByNameNegative13() throws Exception {
        assertNotNull(this.engineManager, "Script engine manager was not created");
        ScriptEngine scriptEngine = this.engineManager.getEngineByName(" " + Constants.EngineNames.ENGINE_NAME_rhino);
        assertNull(scriptEngine, "JavaScript engine manager was found but it's not expected");
    }

    /**
     * Test if none script engine is found using wrong name.
     * @throws Exception if this test case fails.
     */
    protected void testGetEngineByNameNegative14() throws Exception {
        assertNotNull(this.engineManager, "Script engine manager was not created");
        ScriptEngine scriptEngine = this.engineManager.getEngineByName("\b" + Constants.EngineNames.ENGINE_NAME_rhino);
        assertNull(scriptEngine, "JavaScript engine manager was found but it's not expected");
    }

    /**
     * Test if script engine could be found using extension "js"
     * @throws Exception this exception is thrown if none script engine could be found.
     */
    protected void testGetEngineByExtension() throws Exception {
        assertNotNull(this.engineManager, "Script engine manager was not created");
        ScriptEngine scriptEngine = this.engineManager.getEngineByExtension(Constants.FileExtensions.EXTENSION_js);
        assertNotNull(scriptEngine, "JavaScript engine manager not found");
    }

    /**
     * Test if NPE is thrown if getEngineByExtension() is called with null.
     * @throws Exception if this test case fails.
     */
    protected void testGetEngineByExtensionNegative1() throws Exception {
        assertNotNull(this.engineManager, "Script engine manager was not created");
        try {
            @SuppressWarnings("unused")
            ScriptEngine scriptEngine = this.engineManager.getEngineByExtension(null);
        }
        catch (NullPointerException e)
        {
            return;
        }
        throw new Exception("NPE was not thrown as expected");
    }

    /**
     * Test if none script engine is found using wrong extension.
     * @throws Exception if this test case fails.
     */
    protected void testGetEngineByExtensionNegative2() throws Exception {
        assertNotNull(this.engineManager, "Script engine manager was not created");
        ScriptEngine scriptEngine = this.engineManager.getEngineByExtension("");
        assertNull(scriptEngine, "JavaScript engine manager was found but it's not expected");
    }

    /**
     * Test if none script engine is found using wrong extension.
     * @throws Exception if this test case fails.
     */
    protected void testGetEngineByExtensionNegative3() throws Exception {
        assertNotNull(this.engineManager, "Script engine manager was not created");
        ScriptEngine scriptEngine = this.engineManager.getEngineByExtension("  ");
        assertNull(scriptEngine, "JavaScript engine manager was found but it's not expected");
    }

    /**
     * Test if none script engine is found using wrong extension.
     * @throws Exception if this test case fails.
     */
    protected void testGetEngineByExtensionNegative4() throws Exception {
        assertNotNull(this.engineManager, "Script engine manager was not created");
        ScriptEngine scriptEngine = this.engineManager.getEngineByExtension("   ");
        assertNull(scriptEngine, "JavaScript engine manager was found but it's not expected");
    }

    /**
     * Test if none script engine is found using wrong extension.
     * @throws Exception if this test case fails.
     */
    protected void testGetEngineByExtensionNegative5() throws Exception {
        assertNotNull(this.engineManager, "Script engine manager was not created");
        ScriptEngine scriptEngine = this.engineManager.getEngineByExtension("\t");
        assertNull(scriptEngine, "JavaScript engine manager was found but it's not expected");
    }

    /**
     * Test if none script engine is found using wrong extension.
     * @throws Exception if this test case fails.
     */
    protected void testGetEngineByExtensionNegative6() throws Exception {
        assertNotNull(this.engineManager, "Script engine manager was not created");
        ScriptEngine scriptEngine = this.engineManager.getEngineByExtension(" \t");
        assertNull(scriptEngine, "JavaScript engine manager was found but it's not expected");
    }

    /**
     * Test if none script engine is found using wrong extension.
     * @throws Exception if this test case fails.
     */
    protected void testGetEngineByExtensionNegative7() throws Exception {
        assertNotNull(this.engineManager, "Script engine manager was not created");
        ScriptEngine scriptEngine = this.engineManager.getEngineByExtension("\b");
        assertNull(scriptEngine, "JavaScript engine manager was found but it's not expected");
    }

    /**
     * Test if none script engine is found using wrong extension.
     * @throws Exception if this test case fails.
     */
    protected void testGetEngineByExtensionNegative8() throws Exception {
        assertNotNull(this.engineManager, "Script engine manager was not created");
        ScriptEngine scriptEngine = this.engineManager.getEngineByExtension("\b\b");
        assertNull(scriptEngine, "JavaScript engine manager was found but it's not expected");
    }

    /**
     * Test if none script engine is found using wrong extension.
     * @throws Exception if this test case fails.
     */
    protected void testGetEngineByExtensionNegative9() throws Exception {
        assertNotNull(this.engineManager, "Script engine manager was not created");
        ScriptEngine scriptEngine = this.engineManager.getEngineByExtension(" \b\b");
        assertNull(scriptEngine, "JavaScript engine manager was found but it's not expected");
    }

    /**
     * Test if none script engine is found using wrong extension.
     * @throws Exception if this test case fails.
     */
    protected void testGetEngineByExtensionNegative10() throws Exception {
        assertNotNull(this.engineManager, "Script engine manager was not created");
        ScriptEngine scriptEngine = this.engineManager.getEngineByExtension("\000");
        assertNull(scriptEngine, "JavaScript engine manager was found but it's not expected");
    }

    /**
     * Test if none script engine is found using wrong extension.
     * @throws Exception if this test case fails.
     */
    protected void testGetEngineByExtensionNegative11() throws Exception {
        assertNotNull(this.engineManager, "Script engine manager was not created");
        ScriptEngine scriptEngine = this.engineManager.getEngineByExtension("\u0000");
        assertNull(scriptEngine, "JavaScript engine manager was found but it's not expected");
    }

    /**
     * Test if none script engine is found using wrong extension.
     * @throws Exception if this test case fails.
     */
    protected void testGetEngineByExtensionNegative12() throws Exception {
        assertNotNull(this.engineManager, "Script engine manager was not created");
        ScriptEngine scriptEngine = this.engineManager.getEngineByExtension("js ");
        assertNull(scriptEngine, "JavaScript engine manager was found but it's not expected");
    }

    /**
     * Test if none script engine is found using wrong extension.
     * @throws Exception if this test case fails.
     */
    protected void testGetEngineByExtensionNegative13() throws Exception {
        assertNotNull(this.engineManager, "Script engine manager was not created");
        ScriptEngine scriptEngine = this.engineManager.getEngineByExtension("\tjs");
        assertNull(scriptEngine, "JavaScript engine manager was found but it's not expected");
    }

    /**
     * Test if none script engine is found using wrong extension.
     * @throws Exception if this test case fails.
     */
    protected void testGetEngineByExtensionNegative14() throws Exception {
        assertNotNull(this.engineManager, "Script engine manager was not created");
        ScriptEngine scriptEngine = this.engineManager.getEngineByExtension("js\t");
        assertNull(scriptEngine, "JavaScript engine manager was found but it's not expected");
    }

    /**
     * Test if none script engine is found using wrong extension.
     * @throws Exception if this test case fails.
     */
    protected void testGetEngineByExtensionNegative15() throws Exception {
        assertNotNull(this.engineManager, "Script engine manager was not created");
        ScriptEngine scriptEngine = this.engineManager.getEngineByExtension(" js");
        assertNull(scriptEngine, "JavaScript engine manager was found but it's not expected");
    }

    /**
     * Test if none script engine is found using wrong extension.
     * @throws Exception if this test case fails.
     */
    protected void testGetEngineByExtensionNegative16() throws Exception {
        assertNotNull(this.engineManager, "Script engine manager was not created");
        ScriptEngine scriptEngine = this.engineManager.getEngineByExtension("\bjs");
        assertNull(scriptEngine, "JavaScript engine manager was found but it's not expected");
    }

    /**
     * Test if script engine can be selected by MIME type text/javascript.
     * @throws Exception if this test case fails.
     */
    protected void testGetEngineByMimeTypeTextJavaScript() throws Exception {
        tryToFindEngineByMimeType(Constants.MimeTypes.MIME_TYPE_TEXT_JAVASCRIPT);
    }

    /**
     * Test if script engine can be selected by MIME type text/ecmascript.
     * @throws Exception if this test case fails.
     */
    protected void testGetEngineByMimeTypeTextEcmaScript() throws Exception {
        tryToFindEngineByMimeType(Constants.MimeTypes.MIME_TYPE_TEXT_ECMASCRIPT);
    }

    /**
     * Test if script engine can be selected by MIME type application/javascript.
     * @throws Exception if this test case fails.
     */
    protected void testGetEngineByMimeTypeApplicationJavaScript() throws Exception {
        tryToFindEngineByMimeType(Constants.MimeTypes.MIME_TYPE_APPLICATION_JAVASCRIPT);
    }

    /**
     * Test if script engine can be selected by MIME type application/ecmascript.
     * @throws Exception if this test case fails.
     */
    protected void testGetEngineByMimeTypeApplicationEcmaScript() throws Exception {
        tryToFindEngineByMimeType(Constants.MimeTypes.MIME_TYPE_APPLICATION_ECMASCRIPT);
    }

    /**
     * Test if NPE is thrown if getEngineByMimeType() is called with null.
     * @throws Exception if this test case fails.
     */
    protected void testGetEngineByMimeTypeNegative1() throws Exception {
        assertNotNull(this.engineManager, "Script engine manager was not created");
        try {
            @SuppressWarnings("unused")
            ScriptEngine scriptEngine = this.engineManager.getEngineByMimeType(null);
        }
        catch (NullPointerException e)
        {
            return;
        }
        throw new Exception("NPE was not thrown as expected");
    }

    /**
     * Test if none script engine is found using wrong MIME type.
     * @throws Exception if this test case fails.
     */
    protected void testGetEngineByMimeTypeNegative2() throws Exception {
        assertNotNull(this.engineManager, "Script engine manager was not created");
        ScriptEngine scriptEngine = this.engineManager.getEngineByMimeType("");
        assertNull(scriptEngine, "JavaScript engine manager was found but it's not expected");
    }

    /**
     * Test if none script engine is found using wrong MIME type.
     * @throws Exception if this test case fails.
     */
    protected void testGetEngineByMimeTypeNegative3() throws Exception {
        assertNotNull(this.engineManager, "Script engine manager was not created");
        ScriptEngine scriptEngine = this.engineManager.getEngineByMimeType("  ");
        assertNull(scriptEngine, "JavaScript engine manager was found but it's not expected");
    }

    /**
     * Test if none script engine is found using wrong MIME type.
     * @throws Exception if this test case fails.
     */
    protected void testGetEngineByMimeTypeNegative4() throws Exception {
        assertNotNull(this.engineManager, "Script engine manager was not created");
        ScriptEngine scriptEngine = this.engineManager.getEngineByMimeType("   ");
        assertNull(scriptEngine, "JavaScript engine manager was found but it's not expected");
    }

    /**
     * Test if none script engine is found using wrong MIME type.
     * @throws Exception if this test case fails.
     */
    protected void testGetEngineByMimeTypeNegative5() throws Exception {
        assertNotNull(this.engineManager, "Script engine manager was not created");
        ScriptEngine scriptEngine = this.engineManager.getEngineByMimeType("\t");
        assertNull(scriptEngine, "JavaScript engine manager was found but it's not expected");
    }

    /**
     * Test if none script engine is found using wrong MIME type.
     * @throws Exception if this test case fails.
     */
    protected void testGetEngineByMimeTypeNegative6() throws Exception {
        assertNotNull(this.engineManager, "Script engine manager was not created");
        ScriptEngine scriptEngine = this.engineManager.getEngineByMimeType(" \t");
        assertNull(scriptEngine, "JavaScript engine manager was found but it's not expected");
    }

    /**
     * Test if none script engine is found using wrong MIME type.
     * @throws Exception if this test case fails.
     */
    protected void testGetEngineByMimeTypeNegative7() throws Exception {
        assertNotNull(this.engineManager, "Script engine manager was not created");
        ScriptEngine scriptEngine = this.engineManager.getEngineByMimeType("\b");
        assertNull(scriptEngine, "JavaScript engine manager was found but it's not expected");
    }

    /**
     * Test if none script engine is found using wrong MIME type.
     * @throws Exception if this test case fails.
     */
    protected void testGetEngineByMimeTypeNegative8() throws Exception {
        assertNotNull(this.engineManager, "Script engine manager was not created");
        ScriptEngine scriptEngine = this.engineManager.getEngineByMimeType("\b\b");
        assertNull(scriptEngine, "JavaScript engine manager was found but it's not expected");
    }

    /**
     * Test if none script engine is found using wrong MIME type.
     * @throws Exception if this test case fails.
     */
    protected void testGetEngineByMimeTypeNegative9() throws Exception {
        assertNotNull(this.engineManager, "Script engine manager was not created");
        ScriptEngine scriptEngine = this.engineManager.getEngineByMimeType(" \b\b");
        assertNull(scriptEngine, "JavaScript engine manager was found but it's not expected");
    }

    /**
     * Test if none script engine is found using wrong MIME type.
     * @throws Exception if this test case fails.
     */
    protected void testGetEngineByMimeTypeNegative10() throws Exception {
        assertNotNull(this.engineManager, "Script engine manager was not created");
        ScriptEngine scriptEngine = this.engineManager.getEngineByMimeType("\000");
        assertNull(scriptEngine, "JavaScript engine manager was found but it's not expected");
    }

    /**
     * Test if none script engine is found using wrong MIME type.
     * @throws Exception if this test case fails.
     */
    protected void testGetEngineByMimeTypeNegative11() throws Exception {
        assertNotNull(this.engineManager, "Script engine manager was not created");
        ScriptEngine scriptEngine = this.engineManager.getEngineByMimeType("\u0000");
        assertNull(scriptEngine, "JavaScript engine manager was found but it's not expected");
    }

    /**
     * Test if none script engine is found using wrong MIME type.
     * @throws Exception if this test case fails.
     */
    protected void testGetEngineByMimeTypeNegative12() throws Exception {
        assertNotNull(this.engineManager, "Script engine manager was not created");
        ScriptEngine scriptEngine = this.engineManager.getEngineByMimeType("js ");
        assertNull(scriptEngine, "JavaScript engine manager was found but it's not expected");
    }

    /**
     * Test if none script engine is found using wrong MIME type.
     * @throws Exception if this test case fails.
     */
    protected void testGetEngineByMimeTypeNegative13() throws Exception {
        assertNotNull(this.engineManager, "Script engine manager was not created");
        ScriptEngine scriptEngine = this.engineManager.getEngineByMimeType("\tjs");
        assertNull(scriptEngine, "JavaScript engine manager was found but it's not expected");
    }

    /**
     * Test if none script engine is found using wrong MIME type.
     * @throws Exception if this test case fails.
     */
    protected void testGetEngineByMimeTypeNegative14() throws Exception {
        assertNotNull(this.engineManager, "Script engine manager was not created");
        ScriptEngine scriptEngine = this.engineManager.getEngineByMimeType("js\t");
        assertNull(scriptEngine, "JavaScript engine manager was found but it's not expected");
    }

    /**
     * Test if none script engine is found using wrong MIME type.
     * @throws Exception if this test case fails.
     */
    protected void testGetEngineByMimeTypeNegative15() throws Exception {
        assertNotNull(this.engineManager, "Script engine manager was not created");
        ScriptEngine scriptEngine = this.engineManager.getEngineByMimeType(" js");
        assertNull(scriptEngine, "JavaScript engine manager was found but it's not expected");
    }

    /**
     * Test if none script engine is found using wrong MIME type.
     * @throws Exception if this test case fails.
     */
    protected void testGetEngineByMimeTypeNegative16() throws Exception {
        assertNotNull(this.engineManager, "Script engine manager was not created");
        ScriptEngine scriptEngine = this.engineManager.getEngineByMimeType("\bjs");
        assertNull(scriptEngine, "JavaScript engine manager was found but it's not expected");
    }

    /**
     * Check if two script engine factories are equals.
     * @throws Exception thrown if script engine factories are not equals.
     */
    private void compareTwoScriptFactories(ScriptEngineFactory f1, ScriptEngineFactory f2) throws Exception {
        assertEquals(f1, f2, "script engine factories differ");
    }

    /**
     * Get script engine factory by name.
     * @throws Exception thrown if script engine factory can not be found
     */
    private ScriptEngineFactory getFactoryByEngineName(String engineName) throws Exception {
        return tryToFindEngineByName(engineName).getFactory();
    }

    /**
     * Get script engine factory by MIME type.
     * @throws Exception thrown if script engine factory can not be found
     */
    private ScriptEngineFactory getFactoryByMimeType(String mimeType) throws Exception {
        return tryToFindEngineByMimeType(mimeType).getFactory();
    }

    /**
     * Compare two script engine factories selected by its name.
     * @throws Exception thrown if script engine factories are not equals.
     */
    private void compareTwoFactoriesGetByEngineName(String engineName1, String engineName2) throws Exception {
        ScriptEngineFactory f1 = getFactoryByEngineName(engineName1);
        ScriptEngineFactory f2 = getFactoryByEngineName(engineName2);
        assertNotNull(f1, "first engine factory is null");
        assertNotNull(f2, "second engine factory is null");
        compareTwoScriptFactories(f1, f2);
    }

    /**
     * Compare two script engine factories selected by its MIME types.
     * @throws Exception thrown if script engine factories are not equals.
     */
    private void compareTwoFactoriesGetByMimeType(String mimeType1, String mimeType2) throws Exception {
        ScriptEngineFactory f1 = getFactoryByMimeType(mimeType1);
        ScriptEngineFactory f2 = getFactoryByMimeType(mimeType2);
        assertNotNull(f1, "first engine factory is null");
        assertNotNull(f2, "second engine factory is null");
        compareTwoScriptFactories(f1, f2);
    }

    /**
     * Compare two script engine factories selected by its name and MIME type.
     * @throws Exception thrown if script engine factories are not equals.
     */
    private void compareTwoFactoriesGetByNameAndMimeType(String engineName, String mimeType) throws Exception {
        ScriptEngineFactory f1 = getFactoryByEngineName(engineName);
        ScriptEngineFactory f2 = getFactoryByMimeType(mimeType);
        assertNotNull(f1, "first engine factory is null");
        assertNotNull(f2, "second engine factory is null");
        compareTwoScriptFactories(f1, f2);
    }

    /**
     * Test if two script engine factories get by name are equal.
     * @throws Exception thrown if script engine factories are not equals.
     */
    protected void testIfTwoEnginesFactoriesAreEqual1() throws Exception {
        compareTwoFactoriesGetByEngineName(Constants.EngineNames.ENGINE_NAME_javascript, Constants.EngineNames.ENGINE_NAME_javascript);
    }

    /**
     * Test if two script engine factories get by name are equal.
     * @throws Exception thrown if script engine factories are not equals.
     */
    protected void testIfTwoEnginesFactoriesAreEqual2() throws Exception {
        compareTwoFactoriesGetByEngineName(Constants.EngineNames.ENGINE_NAME_javascript, Constants.EngineNames.ENGINE_NAME_JavaScript);
    }

    /**
     * Test if two script engine factories get by name are equal.
     * @throws Exception thrown if script engine factories are not equals.
     */
    protected void testIfTwoEnginesFactoriesAreEqual3() throws Exception {
        compareTwoFactoriesGetByEngineName(Constants.EngineNames.ENGINE_NAME_javascript, Constants.EngineNames.ENGINE_NAME_ecmascript);
    }

    /**
     * Test if two script engine factories get by name are equal.
     * @throws Exception thrown if script engine factories are not equals.
     */
    protected void testIfTwoEnginesFactoriesAreEqual4() throws Exception {
        compareTwoFactoriesGetByEngineName(Constants.EngineNames.ENGINE_NAME_javascript, Constants.EngineNames.ENGINE_NAME_ECMAScript);
    }

    /**
     * Test if two script engine factories get by name are equal.
     * @throws Exception thrown if script engine factories are not equals.
     */
    protected void testIfTwoEnginesFactoriesAreEqual5() throws Exception {
        compareTwoFactoriesGetByEngineName(Constants.EngineNames.ENGINE_NAME_JavaScript, Constants.EngineNames.ENGINE_NAME_JavaScript);
    }

    /**
     * Test if two script engine factories get by name are equal.
     * @throws Exception thrown if script engine factories are not equals.
     */
    protected void testIfTwoEnginesFactoriesAreEqual6() throws Exception {
        compareTwoFactoriesGetByEngineName(Constants.EngineNames.ENGINE_NAME_JavaScript, Constants.EngineNames.ENGINE_NAME_ecmascript);
    }

    /**
     * Test if two script engine factories get by name are equal.
     * @throws Exception thrown if script engine factories are not equals.
     */
    protected void testIfTwoEnginesFactoriesAreEqual7() throws Exception {
        compareTwoFactoriesGetByEngineName(Constants.EngineNames.ENGINE_NAME_JavaScript, Constants.EngineNames.ENGINE_NAME_ECMAScript);
    }

    /**
     * Test if two script engine factories get by name are equal.
     * @throws Exception thrown if script engine factories are not equals.
     */
    protected void testIfTwoEnginesFactoriesAreEqual8() throws Exception {
        compareTwoFactoriesGetByEngineName(Constants.EngineNames.ENGINE_NAME_ecmascript, Constants.EngineNames.ENGINE_NAME_ecmascript);
    }

    /**
     * Test if two script engine factories get by name are equal.
     * @throws Exception thrown if script engine factories are not equals.
     */
    protected void testIfTwoEnginesFactoriesAreEqual9() throws Exception {
        compareTwoFactoriesGetByEngineName(Constants.EngineNames.ENGINE_NAME_ecmascript, Constants.EngineNames.ENGINE_NAME_ECMAScript);
    }

    /**
     * Test if two script engine factories get by name are equal.
     * @throws Exception thrown if script engine factories are not equals.
     */
    protected void testIfTwoEnginesFactoriesAreEqual10() throws Exception {
        compareTwoFactoriesGetByEngineName(Constants.EngineNames.ENGINE_NAME_ECMAScript, Constants.EngineNames.ENGINE_NAME_ECMAScript);
    }

    /**
     * Test if two script engine factories get by MIME type are equal.
     * @throws Exception thrown if script engine factories are not equals.
     */
    protected void testIfTwoEnginesFactoriesAreEqual11() throws Exception {
        compareTwoFactoriesGetByMimeType(Constants.MimeTypes.MIME_TYPE_TEXT_JAVASCRIPT, Constants.MimeTypes.MIME_TYPE_TEXT_JAVASCRIPT);
    }

    /**
     * Test if two script engine factories get by MIME type are equal.
     * @throws Exception thrown if script engine factories are not equals.
     */
    protected void testIfTwoEnginesFactoriesAreEqual12() throws Exception {
        compareTwoFactoriesGetByMimeType(Constants.MimeTypes.MIME_TYPE_TEXT_JAVASCRIPT, Constants.MimeTypes.MIME_TYPE_TEXT_ECMASCRIPT);
    }

    /**
     * Test if two script engine factories get by MIME type are equal.
     * @throws Exception thrown if script engine factories are not equals.
     */
    protected void testIfTwoEnginesFactoriesAreEqual13() throws Exception {
        compareTwoFactoriesGetByMimeType(Constants.MimeTypes.MIME_TYPE_TEXT_JAVASCRIPT, Constants.MimeTypes.MIME_TYPE_APPLICATION_JAVASCRIPT);
    }

    /**
     * Test if two script engine factories get by MIME type are equal.
     * @throws Exception thrown if script engine factories are not equals.
     */
    protected void testIfTwoEnginesFactoriesAreEqual14() throws Exception {
        compareTwoFactoriesGetByMimeType(Constants.MimeTypes.MIME_TYPE_TEXT_JAVASCRIPT, Constants.MimeTypes.MIME_TYPE_APPLICATION_ECMASCRIPT);
    }

    /**
     * Test if two script engine factories get by name and MIME type are equal.
     * @throws Exception thrown if script engine factories are not equals.
     */
    protected void testIfTwoEnginesFactoriesAreEqual15() throws Exception {
        compareTwoFactoriesGetByNameAndMimeType(Constants.EngineNames.ENGINE_NAME_javascript, Constants.MimeTypes.MIME_TYPE_TEXT_JAVASCRIPT);
    }

    /**
     * Test if two script engine factories get by name and MIME type are equal.
     * @throws Exception thrown if script engine factories are not equals.
     */
    protected void testIfTwoEnginesFactoriesAreEqual16() throws Exception {
        compareTwoFactoriesGetByNameAndMimeType(Constants.EngineNames.ENGINE_NAME_javascript, Constants.MimeTypes.MIME_TYPE_TEXT_ECMASCRIPT);
    }

    /**
     * Test if two script engine factories get by name and MIME type are equal.
     * @throws Exception thrown if script engine factories are not equals.
     */
    protected void testIfTwoEnginesFactoriesAreEqual17() throws Exception {
        compareTwoFactoriesGetByNameAndMimeType(Constants.EngineNames.ENGINE_NAME_javascript, Constants.MimeTypes.MIME_TYPE_APPLICATION_JAVASCRIPT);
    }

    /**
     * Test if two script engine factories get by name and MIME type are equal.
     * @throws Exception thrown if script engine factories are not equals.
     */
    protected void testIfTwoEnginesFactoriesAreEqual18() throws Exception {
        compareTwoFactoriesGetByNameAndMimeType(Constants.EngineNames.ENGINE_NAME_javascript, Constants.MimeTypes.MIME_TYPE_APPLICATION_ECMASCRIPT);
    }

    /**
     * Entry point to this test case.
     *
     * @param args parameters passed from command line
     */
    public static void main(String[] args) {
        new ScriptEngineTest().doTests(args);
    }

}

